==> vtk6-6.3.0-2-aarch64.pkg.tar.xz: vtk/vtkInteractorStyleUser.java <==
// java wrapper for vtkInteractorStyleUser object
//

package vtk;
import vtk.*;

public class vtkInteractorStyleUser extends vtkInteractorStyle
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int[]  GetLastPos_2();
  public int[]  GetLastPos()
    { return GetLastPos_2(); }

  private native int[]  GetOldPos_3();
  public int[]  GetOldPos()
    { return GetOldPos_3(); }

  private native int GetShiftKey_4();
  public int GetShiftKey()
    { return GetShiftKey_4(); }

  private native int GetCtrlKey_5();
  public int GetCtrlKey()
    { return GetCtrlKey_5(); }

  private native int GetChar_6();
  public int GetChar()
    { return GetChar_6(); }

  private native String GetKeySym_7();
  public String GetKeySym()
    { return GetKeySym_7(); }

  private native int GetButton_8();
  public int GetButton()
    { return GetButton_8(); }

  private native void OnMouseMove_9();
  public void OnMouseMove()
    { OnMouseMove_9(); }

  private native void OnLeftButtonDown_10();
  public void OnLeftButtonDown()
    { OnLeftButtonDown_10(); }

  private native void OnLeftButtonUp_11();
  public void OnLeftButtonUp()
    { OnLeftButtonUp_11(); }

  private native void OnMiddleButtonDown_12();
  public void OnMiddleButtonDown()
    { OnMiddleButtonDown_12(); }

  private native void OnMiddleButtonUp_13();
  public void OnMiddleButtonUp()
    { OnMiddleButtonUp_13(); }

  private native void OnRightButtonDown_14();
  public void OnRightButtonDown()
    { OnRightButtonDown_14(); }

  private native void OnRightButtonUp_15();
  public void OnRightButtonUp()
    { OnRightButtonUp_15(); }

  private native void OnChar_16();
  public void OnChar()
    { OnChar_16(); }

  private native void OnKeyPress_17();
  public void OnKeyPress()
    { OnKeyPress_17(); }

  private native void OnKeyRelease_18();
  public void OnKeyRelease()
    { OnKeyRelease_18(); }

  private native void OnExpose_19();
  public void OnExpose()
    { OnExpose_19(); }

  private native void OnConfigure_20();
  public void OnConfigure()
    { OnConfigure_20(); }

  private native void OnEnter_21();
  public void OnEnter()
    { OnEnter_21(); }

  private native void OnLeave_22();
  public void OnLeave()
    { OnLeave_22(); }

  private native void OnTimer_23();
  public void OnTimer()
    { OnTimer_23(); }

  public vtkInteractorStyleUser() { super(); }

  public vtkInteractorStyleUser(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-18-aarch64.pkg.tar.xz: vtk/vtkInteractorStyleUser.java <==
// java wrapper for vtkInteractorStyleUser object
//

package vtk;
import vtk.*;

public class vtkInteractorStyleUser extends vtkInteractorStyle
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int[]  GetLastPos_2();
  public int[]  GetLastPos()
    { return GetLastPos_2(); }

  private native int[]  GetOldPos_3();
  public int[]  GetOldPos()
    { return GetOldPos_3(); }

  private native int GetShiftKey_4();
  public int GetShiftKey()
    { return GetShiftKey_4(); }

  private native int GetCtrlKey_5();
  public int GetCtrlKey()
    { return GetCtrlKey_5(); }

  private native int GetChar_6();
  public int GetChar()
    { return GetChar_6(); }

  private native String GetKeySym_7();
  public String GetKeySym()
    { return GetKeySym_7(); }

  private native int GetButton_8();
  public int GetButton()
    { return GetButton_8(); }

  private native void OnMouseMove_9();
  public void OnMouseMove()
    { OnMouseMove_9(); }

  private native void OnLeftButtonDown_10();
  public void OnLeftButtonDown()
    { OnLeftButtonDown_10(); }

  private native void OnLeftButtonUp_11();
  public void OnLeftButtonUp()
    { OnLeftButtonUp_11(); }

  private native void OnMiddleButtonDown_12();
  public void OnMiddleButtonDown()
    { OnMiddleButtonDown_12(); }

  private native void OnMiddleButtonUp_13();
  public void OnMiddleButtonUp()
    { OnMiddleButtonUp_13(); }

  private native void OnRightButtonDown_14();
  public void OnRightButtonDown()
    { OnRightButtonDown_14(); }

  private native void OnRightButtonUp_15();
  public void OnRightButtonUp()
    { OnRightButtonUp_15(); }

  private native void OnMouseWheelForward_16();
  public void OnMouseWheelForward()
    { OnMouseWheelForward_16(); }

  private native void OnMouseWheelBackward_17();
  public void OnMouseWheelBackward()
    { OnMouseWheelBackward_17(); }

  private native void OnChar_18();
  public void OnChar()
    { OnChar_18(); }

  private native void OnKeyPress_19();
  public void OnKeyPress()
    { OnKeyPress_19(); }

  private native void OnKeyRelease_20();
  public void OnKeyRelease()
    { OnKeyRelease_20(); }

  private native void OnExpose_21();
  public void OnExpose()
    { OnExpose_21(); }

  private native void OnConfigure_22();
  public void OnConfigure()
    { OnConfigure_22(); }

  private native void OnEnter_23();
  public void OnEnter()
    { OnEnter_23(); }

  private native void OnLeave_24();
  public void OnLeave()
    { OnLeave_24(); }

  private native void OnTimer_25();
  public void OnTimer()
    { OnTimer_25(); }

  public vtkInteractorStyleUser() { super(); }

  public vtkInteractorStyleUser(long id) { super(id); }
  public native long   VTKInit();

}
